@@ -1,6 +1,7 @@
 """Distribution base class
 """
 from abc import ABC, abstractmethod
+from collections import namedtuple
 
 
 class BaseDistribution(ABC):
@@ -11,6 +12,9 @@ class BaseDistribution(ABC):
     (`y`) and the outputs of the xgboost Booster (`params`).
     """
 
+    def __init__(self):
+        self.Predictions = namedtuple("Predictions", (p for p in self.params))
+
     @property
     @abstractmethod
     def params(self):
